@@ -16,7 +16,7 @@ def _repl_citation(match: re.Match):
     source = md.markdown(source)
 
     # Put everything into HTML
-    return f'<blockquote>\n<p>\n{quote}\n</p>\n<cite>{source}</cite>\n</blockquote>'
+    return f'<blockquote>\n{quote}\n<cite>{source}</cite>\n</blockquote>'
 
 
 def citation(document: str):
